#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-5F6iv8tcLtrJB8GP4rvSDj
key:                  structured-0.1.1-5F6iv8tcLtrJB8GP4rvSDj
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  c0555572dd396a74cc2b6794969b88f8
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-5F6iv8tcLtrJB8GP4rvSDj
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    scientific-0.3.8.1-38VvnYA00bD5k7zFFQre1V
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    time-compat-1.9.9-9gtURn2ujaxHw9cep6r426 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    uuid-types-1.0.6-AM34zGGUsAQJc9P8ZgCl68
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

